﻿(function (argThis) {
    var NameOfThisUIScript = "TLFolder";
    //Name of the script that will be triggered when a layer is double-clicked.
    var NameOfWQProScript = "TLFolderWQPro.jsx";
    //--------------------------------------------------------------------------------
    //Function to create a window or panel.
    function createUI(argObj, NameOfThisUIScript) {
        var ui = (argObj instanceof Panel) ? argObj : new Window("palette", NameOfThisUIScript, undefined, { resizeable: true });
        ui.margins = [5, 5, 5, 5];
        ui.spacing = 6;
        ui.preferredSize = [200, 200];
        ui.onResize = ui.onResizing = function () { ui.layout.resize(); }
        var gpEnabled = ui.add("group { orientation: 'row', alignment : ['fill', 'top'], margins : [0, 0, 0, 0], spacing : 0 }");
        gpEnabled.add("statictext { text : 'Active :'  , preferredSize : [-1,20], alignment :  [ 'left','top' ] }");
        gpEnabled.add("group { preferredSize : [2,20]}");
        ui.btOn = gpEnabled.add("button { text : 'ON'  , preferredSize : [-1,20], alignment :  [ 'fill','top' ] }");
        ui.btOff = gpEnabled.add("button { text : 'OFF'  , preferredSize : [-1,20], alignment :  [ 'fill','top' ] }");
        ui.btAdd = ui.add("button { text : 'Add TLFolder'  , preferredSize : [-1,20], alignment :  [ 'fill','fill' ] }");
        ui.btAddWide = ui.add("button { text : 'Add Wide TLFolder'  , preferredSize : [-1,20], alignment :  [ 'fill','fill' ] }");
        ui.btChangeWdw = ui.add("button { text : 'Change Layers to TLFolders'  , preferredSize : [-1,20], alignment :  [ 'fill','top' ] }");
        return ui;
    }
    //--------------------------------------------------------------------------------
    //Create a window or panel.
    var wdwOrPnl = createUI(argThis);
    if (wdwOrPnl instanceof Window) { wdwOrPnl.center(); wdwOrPnl.show(); }
    else if (wdwOrPnl instanceof Panel) { wdwOrPnl.layout.layout(true); }
    //--------------------------------------------------------------------------------
    //These are buttons that determine which script have the right to use WQPro.
    wdwOrPnl.btOn.onClick = function () {
        app.settings.saveSetting("WQPro", "activeScript", NameOfWQProScript);
    }
    wdwOrPnl.btOff.onClick = function () {
        app.settings.saveSetting("WQPro", "activeScript", "");
    }
    //--------------------------------------------------------------------------------
    //This is a folder creation button, It automatically adjusts the length of the folder layer.
    wdwOrPnl.btAdd.onClick = function () {
        addTLFolder(true);
    }
    //This is a folder creation button,
    wdwOrPnl.btAddWide.onClick = function () {
        addTLFolder(false);
    }
    function addTLFolder(aIsAdjusted) {
        try{
            app.beginUndoGroup("Add TLFolder");
            var cmp = app.project.activeItem;
            var selLyrs = cmp.selectedLayers;
            var shpLyr = cmp.layers.addShape();
            shpLyr.label = 0;
            shpLyr.name = "TLFolder_v";
            shpLyr.enabled = false;
            var ctrlEft = shpLyr.effect.addProperty("ADBE Layer Control");
            ctrlEft.name = "TLFolder";
            if( selLyrs.length !== 0){
                selLyrs.sort(function(a,b){ return (a.index - b.index);} );
                shpLyr.moveBefore(selLyrs[0]);
            }
            if( aIsAdjusted ){
                if (selLyrs.length === 0) { return; }
                selLyrs.sort(function (a, b) { return (a.inPoint - b.inPoint); });
                var inTime = selLyrs[0].inPoint;
                selLyrs.sort(function (a, b) { return (a.outPoint - b.outPoint); });
                var outTime = selLyrs[selLyrs.length - 1].outPoint;
                shpLyr.inPoint = inTime;
                shpLyr.outPoint = outTime;
            }
            app.endUndoGroup();
        }catch(err){
            alert( err.message + "\n" + err.line );
            return;
        }
    }
    //--------------------------------------------------------------------------------
    //Change specific layers to TL folders.
    wdwOrPnl.btChangeWdw.onClick = function () {
        var wdw = new Window("palette", "Change specific layers to TL folders", undefined,);
        wdw.margins = [8, 8, 8, 8];
        wdw.spacing = 6;
        wdw.preferredSize = [200, 200];
        wdw.add("statictext{ text: 'Enter the conditions for the layer to be changed to the TL folder.', preferredSize : [-1,20], alignment : ['fill','fill'] }");
        var gpNL = wdw.add("group{ orientation: 'column', alignment : ['fill', 'fill'] , margins : [0, 0, 0, 0] , spacing : 4 }");   
        gpNL.add("statictext{ text: 'Name (Can be a regular expression) & Label', preferredSize : [-1,20], alignment : ['fill','fill'] }");
        wdw.etName = gpNL.add("edittext{ text: '', alignment : ['fill','fill'] }");
        wdw.etName.text = "^TLFolder.+$";
        wdw.etLabel = gpNL.add("edittext{ text: '0', alignment : ['fill','fill'] }");
        wdw.add("statictext{ text: 'Select Comps in the Project Panel and Press the button below.', preferredSize : [-1,20], alignment : ['fill','fill'] }");
        wdw.btChange = wdw.add("button { text : 'Change'  , preferredSize : [-1,20], alignment :  [ 'fill','top' ] }");
        wdw.btChange.onClick = function () {
            try{
                app.beginUndoGroup("Change Layers to TLFolders");
                var label = parseInt(wdw.etLabel.text);
                if( isNaN(label) ){ label = null;}
                var name =wdw.etName.text;
                var regix = new RegExp( name );
                var selItems = app.project.selection;
                for( var i = 0; i< selItems.length; i++ ){
                    var Item = selItems[i];
                    if( !(Item instanceof CompItem)){ continue;}
                    var allLyrs = Item.layers;
                    for( var j = 1; j<= allLyrs.length; j++ ){
                        var lyr = allLyrs[j];
                        if( lyr.label !== label ){ continue;}
                        if(!(regix.test(lyr.name))){ continue;}
                        if( !( lyr.hasOwnProperty ("effect"))){ continue;}
                        var ctrlEft = lyr.property("effect").addProperty("ADBE Layer Control");
                        ctrlEft.name = "TLFolder";
                        ctrlEft.moveTo(1);
                    }
                }
                app.endUndoGroup();
            }catch(err){
                alert( err.message + "\n" + err.line );
                return;
            }
        }
    wdw.center();
    wdw.show();
    }
})(this);







